@@ -4,7 +4,7 @@ package AuthCAS;
 use strict;
 use vars qw( $VERSION);
 
-$VERSION = '1.3';
+$VERSION = '1.4';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ AuthCAS - Client library for CAS 2.0 authentication server
 
 =head1 VERSION
 
-Version 1.3
+Version 1.4
 
 =head1 DESCRIPTION
 
@@ -375,7 +375,7 @@ sub callCAS {
     
     my @xml = &get_https2($host, $port, $path,{'cafile' =>  $self->{'CAFile'},  'capath' => $self->{'CAPath'}});
 
-    unless (defined $xmlRef) {
+    unless (@xml) {
 	warn $errors;
 	return undef;
     }
@@ -440,15 +440,17 @@ sub get_https2{
 	    return undef;
 	}
 	
-	unless (require IO::Socket::SSL) {
+	unless (eval "require IO::Socket::SSL") {
 	    $errors = sprintf "Unable to use SSL library, IO::Socket::SSL required, install IO-Socket-SSL (CPAN) first\n";
 	    return undef;
 	}
-	
-	unless (require LWP::UserAgent) {
+	require IO::Socket::SSL;
+
+	unless (eval "require LWP::UserAgent") {
 	    $errors = sprintf "Unable to use LWP library, LWP::UserAgent required, install LWP (CPAN) first\n";
 	    return undef;
 	}
+	require  LWP::UserAgent;
 
 	my $ssl_socket;
 
